{% load i18n %}
{% load decorate %}
{% load hk_generic %}

<div class="temporary"
    {% if email.level %}style="margin-left:{{ email.level|multiply:"2" }}em;"{% endif %}>
    <!-- Start email -->
    <div class="email">

        <div class="email-header">
            <div class="email-date inline-block pull-right">
                <span class="date">{% trans "Sent just now, not yet distributed" %}</span>
            </div>
            <div class="gravatar">
                {% gravatar email.sender_address 120 %}
            </div>
            <div class="email-author inline-block">
                <span class="name">{{email.sender_name|default:email.sender_address|escapeemail}}</span>
            </div>
        </div>

        <div class="email-body">
            {{ email|render:email.mailinglist }}
        </div>

        <div class="email-info">
        </div>

    </div>
    <!-- End of email -->
</div>
