# Generated by Django 2.0.9 on 2019-01-27 04:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hyperkitty', '0018_threadcategory_color'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mailinglist',
            name='description',
            field=models.TextField(null=True),
        ),
    ]
