{% load i18n %}
{% load hk_generic %}

                {% for s_thread in suggested_threads %}
                <li><label class="radio"><input type="radio" name="parent" value="{{ s_thread.thread_id }}" />
                    {{ s_thread.subject }}
                    <br/>({% trans "started" %} {{ s_thread.starting_email.date }}, {% trans "last active:" %} {{ s_thread.date_active }},
                    <a href="{% url 'hk_thread' mlist_fqdn=mlist.name threadid=s_thread.thread_id %}">{% trans "see this thread" %}</a>)
                    </label>
                </li>
                {% empty %}
                <li><em>{% trans "(no suggestions)" %}</em></li>
                {% endfor %}
