{% extends "hyperkitty/base.html" %}
{% load i18n %}

{% block content %}
        <style>
            #contentBox
            {
                padding:10px;
                font-family: 'Times New Roman';
                font-size:20px;
                color:#444;
                margin-left:300px;
                margin-top:100px;
            }
            .hello
            {
                font-size:100px;
                color:#444;
                font-family: 'Times New Roman';
            }
            a
            {
                color:#323232;
            }
        </style>

        <div style="margin: 60px 40px 0 40px;">
            <div id="contentBox" style="width:50%; ">
                <span class="hello"> {% trans "Error 500" %} </span>
                <br/><br/>
                <span style="font-size:60px; color:#444;font-family: 'Times New Roman';"> {% trans "Oh No!" %} </span>
                <br/><br/>
                <p>{% trans "Sorry, but the requested page is unavailable due to a server hiccup." %}</p>
                <a href ="{% url 'hk_root' %}">{% trans "Go back home" %}</a>
            </div>
        </div>

{% endblock %}
