# Generated by Django 3.2.11 on 2022-02-13 01:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hyperkitty', '0022_mailinglist_archive_rendering_mode'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mailinglist',
            name='name',
            field=models.CharField(db_index=True, max_length=254, unique=True),
        ),
    ]
