# Generated by Django 2.0.8 on 2019-01-26 16:25

from django.db import migrations

import hyperkitty.models.category


class Migration(migrations.Migration):

    dependencies = [
        ('hyperkitty', '0017_file_attachments'),
    ]

    operations = [
        migrations.AlterField(
            model_name='threadcategory',
            name='color',
            field=hyperkitty.models.category.ColorField(max_length=7),
        ),
    ]
