# Generated by Django 3.0.6 on 2020-06-19 05:23

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('hyperkitty', '0020_auto_20190907_1927'),
    ]

    operations = [
        migrations.AddField(
            model_name='mailinglist',
            name='moderators',
            field=models.ManyToManyField(
                related_name='moderated_lists', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mailinglist',
            name='owners',
            field=models.ManyToManyField(
                related_name='owned_lists', to=settings.AUTH_USER_MODEL),
        ),
    ]
