// Variables common to two or more pages

$headingColor: #666;
$subheadingColor: #999;
$rowBorderColor: #ccc;
$rowSideGutter: 0.5em;
$rowHoverColor: #08c;
$navbarColor: rgb(8, 109, 215);
$linkHoverColor: #ddd;
$linkColor: #08c;
$maroon: rgb(128,0,0);
$grey: #999;
$super-light-grey: #eee;
