# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-03-09 00:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hyperkitty', '0015_mailinglist_id_3'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mailinglist',
            name='archive_policy',
            field=models.IntegerField(
                choices=[(0, 'never'), (1, 'private'), (2, 'public')],
                default=2),
        ),
    ]
