@font-face {
    font-family: 'icomoon';
    src:url('fonts/icomoon.eot?-reqkd2');
    src:url('fonts/icomoon.eot?#iefix-reqkd2') format('embedded-opentype'),
        url('fonts/icomoon.woff?-reqkd2') format('woff'),
        url('fonts/icomoon.ttf?-reqkd2') format('truetype'),
        url('fonts/icomoon.svg?-reqkd2#icomoon') format('svg');
    font-weight: normal;
    font-style: normal;
}

.icomoon {
    font-family: 'icomoon';
    speak: none;
    font-style: normal;
    font-weight: normal;
    font-variant: normal;
    text-transform: none;
    line-height: 1;

    /* Better Font Rendering =========== */
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
