# Generated by Django 2.2 on 2019-09-07 19:27

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hyperkitty', '0019_auto_20190127_null_description'),
    ]

    operations = [
        migrations.AlterField(
            model_name='email',
            name='parent',
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name='children',
                to='hyperkitty.Email'),
        ),
    ]
