{% load i18n %}
{# We currently don't use this template, so missing category_form from context. #}
        {{ category_form.errors.category }}
        <a class="label label-default{% if not user.is_authenticated %} disabled {% endif %}"
           {% if category %}style="background-color:{{category.color}}"{% endif %}
           {% if user.is_authenticated %}
           title="{% trans 'Click to edit' %}"
           {% else %}
           title="{% trans 'You must be logged-in to edit.' %}"
           {% endif %}
           >
            {% if category %}
            {{ category.name|upper }}
            {% else %}
            {% trans "no category" %}
            {% endif %}
        </a>
        <form method="post" action="{% url 'hk_thread_set_category' mlist_fqdn=thread.mailinglist.name threadid=thread.thread_id %}">
            {% csrf_token %}
            {{ category_form.as_p }}
        </form>

