{% load i18n %}

        <h3 id="tag-title">{% trans "tags" %} </h3>
        {% if thread.tags.count %}
        <ul class="list-inline">
            {% for tag in thread.tags.distinct %}
            <li>
                <a href="{#% url 'hk_search_tag' mlist_fqdn=thread.mailinglist.name tag=tag.name %#}"
                   title="{% trans 'Search for tag' %} {{ tag.name|escape }}">{{ tag.name }}</a>
                {% if user in tag.users.all %}
                <form method="post" class="rmtag" action="{% url 'hk_tags' mlist_fqdn=thread.mailinglist.name threadid=thread.thread_id %}">
                    {% csrf_token %}
                    <input type="hidden" name="action" value="rm" />
                    <input type="hidden" name="tag" value="{{ tag.name|escape }}" />
                    <a href="#rmtag" title="{% trans 'Remove' %}">&times;</a>
                </form>
                {% endif %}
                {% if not forloop.last %} <span>|</span> {% endif %}
            </li>
            {% endfor %}
        </ul>
        {% endif %}
