{% load i18n %}

{% if form.fields.sender.choices|length > 1 %}
<p class="text-muted send-as">
    {% trans "This message will be sent as:" %}
    <a href="" class="send-as-default" title="{% trans 'Change sender' %}">
        {{ form.sender.value }}</a>
    {{ form.sender }}
    {% comment %}
        Open a new window. I know it's bad behavior but there's a big risk
        of a user loosing the message they are composing.
    {% endcomment %}
    <a href="{% url 'account_email' %}"
       target="_blank" class="send-as-add-address">
        {% trans "Link another address" %}
        <i class="fa fa-external-link" aria-hidden="true"></i></a>
</p>
{% endif %}
<p class="text-muted">{% trans "If you aren't a current list member, sending this message will subscribe you." %}</p>
