{% extends "hyperkitty/base.html" %}
{% load i18n %}
{% load hk_generic %}


{% block head_title %}
{% trans "Not implemented yet" %} - {{ block.super }}
{% endblock %}

{% block content %}

<h1>{% trans "Not implemented" %}</h1>
<p class="">
    {% trans "This feature has not been implemented yet, sorry." %}
</p>

{% endblock %}

