//=== User profile page ==/
.user-profile {
    tr.list-address {
        font-weight: bold;
        background: $rowBorderColor;
    }
}

table.user-data {
    font-size: 95%;
    th {
        font-weight: bold;
        padding-left: 0 !important; // override boostrap default
    }
    tr.gravatar td {
        vertical-align: middle;
    }
    tr:first-child > td,
    tr:first-child > th {
        border-top: 0;
    }
}
